Clazz.declarePackage("javajs.api");
Clazz.declareInterface(javajs.api, "BytePoster");
;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
